import CSSClasses from '../Helpers/CSSClasses';
import Fieldset from './Fieldset';
import Events from '../Actions/Events';
/**
 * Class Form.
 *
 * @since 1.0.0
 */
export default class Form {
    id;
    fieldsets = [];
    classes;
    formValues = {};
    currentFieldsetId = '';
    navigationData;
    events;
    /**
     * Initializing form data.
     *
     * @param formData Formdata from JSON file.
     *
     * @since 1.0.0
     */
    constructor(formData, formValues = {}) {
        this.id = formData.id;
        this.currentFieldsetId = formData.fieldsets[0].id;
        this.formValues = formValues;
        let fieldset;
        formData.fieldsets.forEach((fieldsetData) => {
            fieldset = new Fieldset(fieldsetData, formValues);
            this.fieldsets.push(fieldset);
        });
        this.classes = new CSSClasses(formData.classes);
        this.navigationData = formData.navigation;
        this.events = new Events(formData.events, this.formValues);
    }
    /**
     * Execute triggers.
     *
     * @return boolean True if all events were executed successfully.
     *
     * @since 1.0.0
     */
    executeEvents(trigger) {
        if (!this.events.exists()) {
            return true;
        }
        return this.events.execute(trigger);
    }
    /**
     * Execute callbacks.
     *
     * @param trigger Trigger to execute.
     *
     * @since 1.0.0
     */
    executeFieldCallbacks(trigger) {
        this.fieldsets.forEach((fieldset) => {
            fieldset.fields.forEach((field) => {
                if (field.valueCallback === undefined) {
                    return;
                }
                if (field.valueCallback.trigger !== trigger) {
                    return;
                }
                this.formValues[field.id] = field.valueCallback.execute();
            });
        });
    }
    /**
     * Set current fieldset.
     *
     * @param fieldsetId Id of fieldset.
     *
     * @since 1.0.0
     */
    setCurrentFieldset(fieldsetId) {
        if (!this.fieldsetExists(fieldsetId)) {
            console.error('Fieldset with id "' + fieldsetId + '" does not exist.');
            return;
        }
        this.currentFieldsetId = fieldsetId;
    }
    /**
     * Check if fieldset exists.
     *
     * @param fieldsetId Fieldset id.
     *
     * @returns boolean True if fieldset exists, false if not.
     *
     * @since 1.0.0
     */
    fieldsetExists(fieldsetId) {
        return this.fieldsets.find((fieldset) => {
            return fieldset.id === fieldsetId;
        }) !== undefined;
    }
    /**
     * Get current fieldset id.
     *
     * @returns string Current fieldset id.
     *
     * @since 1.0.0
     */
    getCurrentFieldsetId() {
        return this.currentFieldsetId;
    }
    /**
     * Get current fieldset.
     *
     * @returns {Fieldset} Fieldset object.
     *
     * @since 1.0.0
     */
    getCurrentFieldset() {
        return this.fieldsets.find((fieldset) => {
            return fieldset.id === this.currentFieldsetId;
        });
    }
    /**
     * Get value by field id.
     *
     * @param fieldId Field id.
     *
     * @returns {any} Value of field.
     *
     * @since 1.0.0
     */
    getValue(fieldId) {
        return this.formValues[fieldId];
    }
    /**
     * Set value by field id.
     *
     * @param fieldId Field id.
     * @param value Value to set.
     *
     * @since 1.0.0
     */
    setValue(fieldId, value) {
        this.formValues[fieldId] = value;
    }
    /**
     * Get form values.
     *
     * @returns [] Form values.
     *
     * @since 1.0.0
     */
    getValues() {
        return this.formValues;
    }
    /**
     * Has navigation data (CSS etc).
     *
     * @returns Boolean True if form has navigation data, false if not.
     *
     * @since 1.0.0
     */
    hasNavigationData() {
        return this.navigationData !== undefined;
    }
}
