import { fieldsetStore } from "../../Stores/FieldsetStore";
import { fieldStore } from "../../Stores/FieldStore";
import CSSClasses from "../Helpers/CSSClasses";
/**
 * Navigation class.
 *
 * @since 1.0.0
 */
export default class Navigation {
    fieldsets;
    form;
    currentFieldset;
    classes;
    buttonsClasses;
    /**
     * Initializing navigation.
     *
     * @param form  Form object.
     * @param navigationData Navigation data.
     *
     * @since 1.0.0
     */
    constructor(form) {
        this.form = form;
        this._setCurrentFieldset(form.getCurrentFieldsetId());
        let classes = form.navigationData !== undefined && form.navigationData.classes !== undefined ? form.navigationData.classes : [];
        let buttonsClasses = form.navigationData !== undefined && form.navigationData.buttonsClasses !== undefined ? form.navigationData.buttonsClasses : [];
        this.classes = new CSSClasses(classes);
        this.buttonsClasses = new CSSClasses(buttonsClasses);
    }
    /**
     * Get current fieldset.
     *
     * @return Current fieldset.
     *
     * @since 1.0.0
     */
    getCurrentFieldset() {
        return this.currentFieldset;
    }
    /**
     * Set previous fieldset.
     *
     * @return Navigation object.
     *
     * @since 1.0.0
     */
    prev() {
        if (!this.hasPrev()) {
            console.error('Fieldset has no previuos fieldset.');
            return;
        }
        this._setCurrentFieldset(this.currentFieldset.prevFieldset);
    }
    /**
     * Set next fieldset.
     *
     * @return Navigation object.
     *
     * @since 1.0.0
     */
    next() {
        if (!this.hasNext()) {
            console.error('Fieldset has no next fieldset.');
            return;
        }
        // Check for errors before going to next fieldset.
        let error = false;
        this.currentFieldset.fields.forEach((field) => {
            if (field.isVisible() && !field.validate()) {
                error = true;
                console.warn(field.id, field.getErrors());
            }
            field.updateAssets();
            fieldStore.set(field);
        });
        if (error) {
            return;
        }
        this._setCurrentFieldset(this.currentFieldset.nextFieldset);
    }
    /**
     * Is there a previous fieldset?
     *
     * @return True if there is a previous fieldset, false if not.
     *
     * @since 1.0.0
     */
    hasPrev() {
        return this.currentFieldset.hasPrev();
    }
    /**
     * Is there a next fieldset?
     *
     * @return True if there is a previous fieldset, false if not.
     *
     * @since 1.0.0
     */
    hasNext() {
        return this.currentFieldset.hasNext();
    }
    /**
     * Set current fieldset.
     *
     * @param fieldsetId Id of fieldset.
     *
     * @since 1.0.0
     */
    _setCurrentFieldset(fieldsetId) {
        this.form.setCurrentFieldset(fieldsetId);
        this.currentFieldset = this.form.getCurrentFieldset();
        fieldsetStore.set(this.currentFieldset);
    }
}
